richardview.majumdar\_lab\_widgets.iot\_relay\_widget module
============================================================

.. automodule:: richardview.majumdar_lab_widgets.iot_relay_widget
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
